% Ragionamento sulle misure in riflessione
% Scopo: dimostrare che da un fit lineare della fase nella detuned short
% position si pu misurare il Q0 di una risonza in riflessione

close all
clear all

fris=2e9;
Q0=15000;
beta=0.2;
%beta=1.2;

% S11 di una risonanza
freq=0.999*fris:fris/1000000:1.001*fris;
[modulus,phase]=s11resonance2(freq,fris,beta,Q0);
S11out=s11resonance(freq,fris,beta,Q0);
% plot dei dati
fig1=myplotSet2;
plot(freq,modulus,'r+','linewidth',1.5)

fig2=myplotSet2;
plot(freq,phase,'go','linewidth',1.5)

% Fit lineare intorno alla risonanza (2*Npoints dati)
Npoints=5;

[val,ind]=min(modulus);  % indice della frequenza di risonanza dal minimo del modulo

% dati nella parte lineare della fase
freqPoints=freq(ind-Npoints:ind+Npoints);
phasePoints=phase(ind-Npoints:ind+Npoints);

[p,unc_p,q,unc_q,rfactor]=regression2(freqPoints,phasePoints);

% Plot dei risultati del fit
figure(fig2);
plot(freq,p*freq+q,'k--','linewidth',1.5)
if beta<1,
    ylim([-0.3,0.3]);
    xlim([0.99995*fris,1.00005*fris]);
else
    ylim([-2,2]);
    xlim([0.99995*fris,1.00005*fris]);
end

% Ricavo beta dal minimo di S11 e Q0 dalla pendenza
freqMeas1=freq(ind);
betaMeas1=(1+real(S11out(ind)))/(1-real(S11out(ind)));
Q0meas1=p*(1-betaMeas1^2)/(4*betaMeas1)*freq(ind);

% Confronto con il fit di S11:  il metodo pi accurato
[fresMeas2,betaMeas2,Q0meas2,lossMeas,unc_fres,unc_beta,unc_q02,unc_loss]=S11fit_attenuation(freq,real(S11out),imag(S11out),beta+0.1,1);

% Confronto con il metodo dell'impedenza: trasformo in impedenza e misuro i
% punti significativi
% impedance is normalised to the caractheristic impedance
impedance=(1+S11out)./(1-S11out);

[betaMeas3,ind2]=max(abs(impedance));
impedanceModulus=abs(impedance);

% Misura di Q0 dalla banda a 3dB (max value * sqrt(2))
leftSide=impedanceModulus(freq<freq(ind2));
[~,indLower]=min(abs(leftSide-betaMeas3/sqrt(2)));

rightSide=impedanceModulus(freq>freq(ind2));
[~,indHigher]=min(abs(rightSide-betaMeas3/sqrt(2)));

freqMeas3=(freq(ind2+indHigher)+freq(indLower))/2;
Q0meas3=freqMeas3/(freq(ind2+indHigher)-freq(indLower));

fig3=myplotSet2;
plot(freq,impedanceModulus,'b+','linewidth',1.5)
plot(freq(indLower),impedanceModulus(indLower),'r+','linewidth',1.5)
plot(freq(ind2+indHigher),impedanceModulus(ind2+indHigher),'r+','linewidth',1.5)

